==> Microsoft-AdCenter-7.03.tar.gz: Microsoft-AdCenter-7.03/lib/Microsoft/AdCenter/CampaignManagementService/GetNegativeKeywordsByCampaignIdsResponse.pm <==
package Microsoft::AdCenter::CampaignManagementService::GetNegativeKeywordsByCampaignIdsResponse;
# Copyright (C) 2010 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::CampaignManagementService::GetNegativeKeywordsByCampaignIdsResponse - Represents "GetNegativeKeywordsByCampaignIdsResponse" in Microsoft AdCenter Campaign Management Service.

=cut

sub _type_name {
    return 'GetNegativeKeywordsByCampaignIdsResponse';
}

sub _namespace_uri {
    return 'https://adcenter.microsoft.com/v7';
}

our @_attributes = (qw/
    CampaignNegativeKeywords
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    CampaignNegativeKeywords => 'ArrayOfCampaignNegativeKeywords',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

__PACKAGE__->mk_accessors(__PACKAGE__->_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 CampaignNegativeKeywords

Gets/sets CampaignNegativeKeywords (ArrayOfCampaignNegativeKeywords)

=cut

==> Microsoft-AdCenter-7.07.tar.gz: Microsoft-AdCenter-7.07/lib/Microsoft/AdCenter/CampaignManagementService/GetNegativeKeywordsByCampaignIdsResponse.pm <==
package Microsoft::AdCenter::CampaignManagementService::GetNegativeKeywordsByCampaignIdsResponse;
# Copyright (C) 2010 Xerxes Tsang
# This program is free software; you can redistribute it and/or modify it
# under the terms of Perl Artistic License.

use strict;
use warnings;

use base qw/Microsoft::AdCenter::ComplexType/;

=head1 NAME

Microsoft::AdCenter::CampaignManagementService::GetNegativeKeywordsByCampaignIdsResponse - Represents "GetNegativeKeywordsByCampaignIdsResponse" in Microsoft AdCenter Campaign Management Service.

=cut

sub _type_name {
    return 'GetNegativeKeywordsByCampaignIdsResponse';
}

sub _namespace_uri {
    return 'https://adcenter.microsoft.com/v7';
}

our @_attributes = (qw/
    CampaignNegativeKeywords
/);

sub _attributes {
    my $self = shift;
    return ($self->SUPER::_attributes, @_attributes);
}

our %_attribute_type = (
    CampaignNegativeKeywords => 'ArrayOfCampaignNegativeKeywords',
);

sub _attribute_type {
    my ($self, $attribute) = @_;
    if (exists $_attribute_type{$attribute}) {
        return $_attribute_type{$attribute};
    }
    return $self->SUPER::_attribute_type($attribute);
}

our %_attribute_min_occurs = (
    CampaignNegativeKeywords => 1,
);

sub _attribute_min_occurs {
    my ($self, $attribute) = @_;
    if (exists $_attribute_min_occurs{$attribute}) {
        return $_attribute_min_occurs{$attribute};
    }
    return $self->SUPER::_attribute_min_occurs($attribute);
}

__PACKAGE__->mk_accessors(@_attributes);

1;

=head1 SYNOPSIS

See L<http://msdn.microsoft.com/en-us/library/ee730328%28v=MSADS.70%29.aspx> for documentation of the various data objects.

=cut

=head1 METHODS

=head2 new

Creates a new instance

=head2 CampaignNegativeKeywords

Gets/sets CampaignNegativeKeywords (ArrayOfCampaignNegativeKeywords)

=cut
